@@ -29,35 +29,35 @@ class Family(family.SubdomainFamily, family.WikimediaFamily):
 
     languages_by_size = [
         'en', 'ceb', 'sv', 'de', 'fr', 'nl', 'ru', 'it', 'es', 'pl', 'war',
-        'vi', 'ja', 'zh', 'ar', 'pt', 'uk', 'arz', 'fa', 'ca', 'sr', 'id',
+        'vi', 'ja', 'zh', 'arz', 'ar', 'pt', 'uk', 'fa', 'ca', 'sr', 'id',
         'no', 'ko', 'fi', 'hu', 'cs', 'sh', 'ro', 'zh-min-nan', 'eu', 'tr',
         'ms', 'eo', 'ce', 'hy', 'he', 'bg', 'da', 'azb', 'sk', 'kk', 'min',
         'hr', 'et', 'lt', 'be', 'el', 'az', 'simple', 'sl', 'gl', 'ur', 'nn',
-        'hi', 'th', 'ka', 'uz', 'la', 'cy', 'ta', 'vo', 'tt', 'ast', 'mk',
-        'lv', 'tg', 'mg', 'af', 'zh-yue', 'bn', 'oc', 'bs', 'sq', 'ky', 'nds',
-        'new', 'be-tarask', 'tl', 'ml', 'te', 'br', 'pms', 'su', 'sw', 'ht',
-        'lb', 'mr', 'vec', 'sco', 'jv', 'pnb', 'ga', 'ba', 'szl', 'is', 'my',
-        'fy', 'cv', 'lmo', 'an', 'wuu', 'pa', 'ne', 'yo', 'bar', 'ku', 'io',
-        'gu', 'diq', 'als', 'ckb', 'kn', 'scn', 'bpy', 'ia', 'qu', 'mn',
-        'bat-smg', 'or', 'si', 'nv', 'cdo', 'ilo', 'yi', 'gd', 'am', 'nap',
-        'bug', 'xmf', 'wa', 'sd', 'hsb', 'mai', 'map-bms', 'fo', 'mzn', 'li',
+        'hi', 'ka', 'th', 'uz', 'la', 'cy', 'ta', 'tt', 'vo', 'mk', 'ast',
+        'lv', 'tg', 'zh-yue', 'bn', 'mg', 'af', 'oc', 'bs', 'sq', 'ky', 'nds',
+        'new', 'be-tarask', 'ml', 'te', 'tl', 'br', 'pms', 'su', 'mr', 'sw',
+        'ht', 'lb', 'sco', 'vec', 'jv', 'pnb', 'ga', 'ba', 'szl', 'is', 'my',
+        'fy', 'cv', 'lmo', 'wuu', 'an', 'pa', 'ne', 'yo', 'bar', 'ku', 'diq',
+        'io', 'gu', 'als', 'ckb', 'kn', 'scn', 'bpy', 'qu', 'ia', 'mn',
+        'bat-smg', 'or', 'nv', 'si', 'cdo', 'ilo', 'gd', 'am', 'yi', 'nap',
+        'bug', 'wa', 'xmf', 'sd', 'hsb', 'mai', 'map-bms', 'fo', 'mzn', 'li',
         'sah', 'eml', 'os', 'ps', 'sa', 'frr', 'bcl', 'zh-classical', 'ace',
-        'mrj', 'mhr', 'hif', 'hak', 'roa-tara', 'pam', 'avk', 'hyw', 'km',
-        'nso', 'gor', 'rue', 'se', 'crh', 'bh', 'shn', 'vls', 'mi', 'as',
-        'nds-nl', 'nah', 'sc', 'vep', 'gan', 'myv', 'ab', 'glk', 'bo', 'co',
-        'so', 'tk', 'sn', 'fiu-vro', 'lrc', 'csb', 'kv', 'ha', 'gv', 'ie',
-        'udm', 'ay', 'pcd', 'zea', 'kab', 'nrm', 'ug', 'sat', 'kw', 'lez',
-        'lij', 'stq', 'haw', 'frp', 'lfn', 'mwl', 'gn', 'gom', 'rm', 'mt',
-        'lad', 'lo', 'zu', 'koi', 'fur', 'olo', 'ban', 'dty', 'ang', 'dsb',
-        'bjn', 'ext', 'ln', 'cbk-zam', 'dv', 'ksh', 'gag', 'pfl', 'tyv', 'pag',
-        'pi', 'av', 'awa', 'bxr', 'xal', 'krc', 'pap', 'za', 'pdc', 'kaa',
-        'rw', 'szy', 'arc', 'to', 'nov', 'jam', 'tpi', 'kbp', 'kbd', 'ig',
-        'na', 'tet', 'inh', 'wo', 'tcy', 'ki', 'jbo', 'atj', 'roa-rup', 'bi',
-        'lbe', 'kg', 'ty', 'ary', 'mdf', 'lg', 'srn', 'xh', 'gcr', 'fj', 'ltg',
-        'chr', 'sm', 'ak', 'got', 'kl', 'pih', 'om', 'cu', 'ny', 'tn', 'tw',
-        'st', 'ts', 'rmy', 'nqo', 'bm', 'chy', 'rn', 'mnw', 'tum', 'ss', 'ch',
-        'iu', 'pnt', 'ady', 'ks', 've', 'ee', 'ik', 'ff', 'sg', 'ti', 'dz',
-        'cr', 'din',
+        'mrj', 'mhr', 'hif', 'hak', 'roa-tara', 'avk', 'pam', 'gor', 'hyw',
+        'km', 'nso', 'rue', 'se', 'crh', 'bh', 'shn', 'vls', 'as', 'mi',
+        'nds-nl', 'nah', 'sc', 'vep', 'gan', 'myv', 'ab', 'glk', 'bo', 'sn',
+        'co', 'so', 'tk', 'fiu-vro', 'lrc', 'csb', 'kv', 'ha', 'ie', 'gv',
+        'udm', 'pcd', 'ay', 'zea', 'kab', 'nrm', 'sat', 'ug', 'lij', 'kw',
+        'lez', 'stq', 'frp', 'lfn', 'zu', 'gn', 'mwl', 'gom', 'rm', 'ban',
+        'mt', 'lo', 'lad', 'koi', 'fur', 'olo', 'dty', 'ang', 'dsb', 'bjn',
+        'ext', 'ln', 'cbk-zam', 'dv', 'ksh', 'gag', 'pfl', 'tyv', 'pag', 'pi',
+        'av', 'awa', 'haw', 'bxr', 'ary', 'xal', 'krc', 'pap', 'za', 'pdc',
+        'kaa', 'rw', 'szy', 'arc', 'to', 'nov', 'jam', 'tpi', 'kbp', 'kbd',
+        'ig', 'na', 'tet', 'inh', 'wo', 'tcy', 'ki', 'jbo', 'atj', 'roa-rup',
+        'bi', 'lbe', 'kg', 'ty', 'lg', 'mdf', 'srn', 'xh', 'gcr', 'ltg', 'fj',
+        'chr', 'ak', 'sm', 'lld', 'kl', 'om', 'got', 'pih', 'cu', 'ny', 'tn',
+        'tw', 'nqo', 'st', 'ts', 'rmy', 'bm', 'mnw', 'chy', 'rn', 'tum', 'ss',
+        'ch', 'iu', 'pnt', 'ady', 'ks', 've', 'ee', 'ik', 'ff', 'sg', 'dz',
+        'ti', 'cr', 'din',
     ]
 
     # Sites we want to edit but not count as real languages
