@@ -17,7 +17,7 @@ class Family(family.SubdomainFamily, family.WikimediaFamily):
     name = 'wikiversity'
 
     languages_by_size = [
-        'de', 'en', 'fr', 'ru', 'zh', 'it', 'cs', 'pt', 'es', 'sv', 'sl', 'fi',
+        'de', 'en', 'fr', 'zh', 'ru', 'it', 'cs', 'pt', 'es', 'sv', 'sl', 'fi',
         'ar', 'el', 'hi', 'ko', 'ja',
     ]
 
