@@ -5,18 +5,12 @@
 #
 # Distributed under the terms of the MIT license.
 #
-from __future__ import absolute_import, division, unicode_literals
-
 import logging
 
+from urllib.parse import urlparse, parse_qs
+
 from pywikibot.exceptions import NoPage, UnknownExtension, LockedPage
 from pywikibot.page import BasePage, User
-from pywikibot.tools import PY2, UnicodeType
-
-if not PY2:
-    from urllib.parse import urlparse, parse_qs
-else:
-    from urlparse import urlparse, parse_qs
 
 
 logger = logging.getLogger('pywiki.wiki.flow')
@@ -45,7 +39,7 @@ class FlowPage(BasePage):
         @raises TypeError: incorrect use of parameters
         @raises ValueError: use of non-Flow-enabled Site
         """
-        super(FlowPage, self).__init__(source, title)
+        super().__init__(source, title)
 
         if not self.site.has_extension('Flow'):
             raise UnknownExtension('site is not Flow-enabled')
@@ -199,7 +193,7 @@ class Topic(FlowPage):
         """
         if not isinstance(board, Board):
             raise TypeError('board must be a pywikibot.flow.Board object.')
-        if not isinstance(root_uuid, UnicodeType):
+        if not isinstance(root_uuid, str):
             raise TypeError('Topic/root UUID must be a string.')
 
         topic = cls(board.site, 'Topic:' + root_uuid)
@@ -305,7 +299,7 @@ class Topic(FlowPage):
 
 
 # Flow non-page-like objects
-class Post(object):
+class Post:
 
     """A post to a Flow discussion topic."""
 
@@ -324,7 +318,7 @@ class Post(object):
             raise TypeError('Page must be a Topic object')
         if not page.exists():
             raise NoPage(page, 'Topic must exist: %s')
-        if not isinstance(uuid, UnicodeType):
+        if not isinstance(uuid, str):
             raise TypeError('Post UUID must be a string')
 
         self._page = page
@@ -377,7 +371,7 @@ class Post(object):
         if 'content' in self._current_revision:
             content = self._current_revision.pop('content')
             assert isinstance(content, dict)
-            assert isinstance(content['content'], UnicodeType)
+            assert isinstance(content['content'], str)
             self._content[content['format']] = content['content']
 
     def _load(self, format='wikitext', load_from_topic=False):
