@@ -72,7 +72,7 @@ def getversion(online=True):
                 'OUTDATED' if hsh1 not in (hsh2, hsh3) else 'ok')
 
     data['hsh'] = data['hsh'][:7]  # make short hash from full hash
-    return '{tag} ({hsh}, {rev}, {date}, {cmp_ver})'.format(**data)
+    return '{tag} ({hsh}, {rev}, {date}, {cmp_ver})'.format_map(data)
 
 
 def getversiondict():
@@ -302,7 +302,7 @@ def getversion_git(path=None):
         tag = '[%s] %s' % (t[0][:-1], '-'.join(t[3:]))
     dp = subprocess.Popen([cmd, '--no-pager',
                            'log', '-1',
-                           '--pretty=format:"%ad|%an|%h|%H|%d"'
+                           '--pretty=format:"%ad|%an|%h|%H|%d"',
                            '--abbrev-commit',
                            '--date=iso'],
                           cwd=_program_dir,
